#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b (http://hl7.org/fhir/StructureDefinition/HealthcareService) on 2019-05-13.
#  2019, SMART Health IT.


from . import domainresource

class HealthcareService(domainresource.DomainResource):
    """ The details of a healthcare service available at a location.
    """

    resource_type = "HealthcareService"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.active = None
        """ Whether this HealthcareService record is in active use.
        Type `bool`. """

        self.appointmentRequired = None
        """ If an appointment is required for access to this service.
        Type `bool`. """

        self.availabilityExceptions = None
        """ Description of availability exceptions.
        Type `str`. """

        self.availableTime = None
        """ Times the Service Site is available.
        List of `HealthcareServiceAvailableTime` items (represented as `dict` in JSON). """

        self.category = None
        """ Broad category of service being performed or delivered.
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        self.characteristic = None
        """ Collection of characteristics (attributes).
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        self.comment = None
        """ Additional description and/or any specific issues not covered
        elsewhere.
        Type `str`. """

        self.communication = None
        """ The language that this service is offered in.
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        self.coverageArea = None
        """ Location(s) service is intended for/available to.
        List of `FHIRReference` items (represented as `dict` in JSON). """

        self.eligibility = None
        """ Specific eligibility requirements required to use the service.
        List of `HealthcareServiceEligibility` items (represented as `dict` in JSON). """

        self.endpoint = None
        """ Technical endpoints providing access to electronic services
        operated for the healthcare service.
        List of `FHIRReference` items (represented as `dict` in JSON). """

        self.extraDetails = None
        """ Extra details about the service that can't be placed in the other
        fields.
        Type `str`. """

        self.identifier = None
        """ External identifiers for this item.
        List of `Identifier` items (represented as `dict` in JSON). """

        self.location = None
        """ Location(s) where service may be provided.
        List of `FHIRReference` items (represented as `dict` in JSON). """

        self.name = None
        """ Description of service as presented to a consumer while searching.
        Type `str`. """

        self.notAvailable = None
        """ Not available during this time due to provided reason.
        List of `HealthcareServiceNotAvailable` items (represented as `dict` in JSON). """

        self.photo = None
        """ Facilitates quick identification of the service.
        Type `Attachment` (represented as `dict` in JSON). """

        self.program = None
        """ Programs that this service is applicable to.
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        self.providedBy = None
        """ Organization that provides this service.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.referralMethod = None
        """ Ways that the service accepts referrals.
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        self.serviceProvisionCode = None
        """ Conditions under which service is available/offered.
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        self.specialty = None
        """ Specialties handled by the HealthcareService.
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        self.telecom = None
        """ Contacts related to the healthcare service.
        List of `ContactPoint` items (represented as `dict` in JSON). """

        self.type = None
        """ Type of service that may be delivered or performed.
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        super(HealthcareService, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(HealthcareService, self).elementProperties()
        js.extend([
            ("active", "active", bool, "boolean", False, None, False),
            ("appointmentRequired", "appointmentRequired", bool, "boolean", False, None, False),
            ("availabilityExceptions", "availabilityExceptions", str, "string", False, None, False),
            ("availableTime", "availableTime", HealthcareServiceAvailableTime, "HealthcareServiceAvailableTime", True, None, False),
            ("category", "category", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
            ("characteristic", "characteristic", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
            ("comment", "comment", str, "string", False, None, False),
            ("communication", "communication", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
            ("coverageArea", "coverageArea", fhirreference.FHIRReference, "Reference", True, None, False),
            ("eligibility", "eligibility", HealthcareServiceEligibility, "HealthcareServiceEligibility", True, None, False),
            ("endpoint", "endpoint", fhirreference.FHIRReference, "Reference", True, None, False),
            ("extraDetails", "extraDetails", str, "markdown", False, None, False),
            ("identifier", "identifier", identifier.Identifier, "Identifier", True, None, False),
            ("location", "location", fhirreference.FHIRReference, "Reference", True, None, False),
            ("name", "name", str, "string", False, None, False),
            ("notAvailable", "notAvailable", HealthcareServiceNotAvailable, "HealthcareServiceNotAvailable", True, None, False),
            ("photo", "photo", attachment.Attachment, "Attachment", False, None, False),
            ("program", "program", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
            ("providedBy", "providedBy", fhirreference.FHIRReference, "Reference", False, None, False),
            ("referralMethod", "referralMethod", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
            ("serviceProvisionCode", "serviceProvisionCode", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
            ("specialty", "specialty", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
            ("telecom", "telecom", contactpoint.ContactPoint, "ContactPoint", True, None, False),
            ("type", "type", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
        ])
        return js


from . import backboneelement

class HealthcareServiceAvailableTime(backboneelement.BackboneElement):
    """ Times the Service Site is available.

    A collection of times that the Service Site is available.
    """

    resource_type = "HealthcareServiceAvailableTime"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.allDay = None
        """ Always available? e.g. 24 hour service.
        Type `bool`. """

        self.availableEndTime = None
        """ Closing time of day (ignored if allDay = true).
        Type `FHIRDate` (represented as `str` in JSON). """

        self.availableStartTime = None
        """ Opening time of day (ignored if allDay = true).
        Type `FHIRDate` (represented as `str` in JSON). """

        self.daysOfWeek = None
        """ mon | tue | wed | thu | fri | sat | sun.
        List of `str` items. """

        super(HealthcareServiceAvailableTime, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(HealthcareServiceAvailableTime, self).elementProperties()
        js.extend([
            ("allDay", "allDay", bool, "boolean", False, None, False),
            ("availableEndTime", "availableEndTime", fhirdate.FHIRDate, "time", False, None, False),
            ("availableStartTime", "availableStartTime", fhirdate.FHIRDate, "time", False, None, False),
            ("daysOfWeek", "daysOfWeek", str, "code", True, None, False),
        ])
        return js


class HealthcareServiceEligibility(backboneelement.BackboneElement):
    """ Specific eligibility requirements required to use the service.

    Does this service have specific eligibility requirements that need to be
    met in order to use the service?
    """

    resource_type = "HealthcareServiceEligibility"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.code = None
        """ Coded value for the eligibility.
        Type `CodeableConcept` (represented as `dict` in JSON). """

        self.comment = None
        """ Describes the eligibility conditions for the service.
        Type `str`. """

        super(HealthcareServiceEligibility, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(HealthcareServiceEligibility, self).elementProperties()
        js.extend([
            ("code", "code", codeableconcept.CodeableConcept, "CodeableConcept", False, None, False),
            ("comment", "comment", str, "markdown", False, None, False),
        ])
        return js


class HealthcareServiceNotAvailable(backboneelement.BackboneElement):
    """ Not available during this time due to provided reason.

    The HealthcareService is not available during this period of time due to
    the provided reason.
    """

    resource_type = "HealthcareServiceNotAvailable"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.description = None
        """ Reason presented to the user explaining why time not available.
        Type `str`. """

        self.during = None
        """ Service not available from this date.
        Type `Period` (represented as `dict` in JSON). """

        super(HealthcareServiceNotAvailable, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(HealthcareServiceNotAvailable, self).elementProperties()
        js.extend([
            ("description", "description", str, "string", False, None, True),
            ("during", "during", period.Period, "Period", False, None, False),
        ])
        return js


import sys
try:
    from . import attachment
except ImportError:
    attachment = sys.modules[__package__ + '.attachment']
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import contactpoint
except ImportError:
    contactpoint = sys.modules[__package__ + '.contactpoint']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
try:
    from . import period
except ImportError:
    period = sys.modules[__package__ + '.period']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b on 2019-05-13.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json

from .fixtures import force_bytes
from .. import chargeitemdefinition
from ..fhirdate import FHIRDate


@pytest.mark.usefixtures("base_settings")
class ChargeItemDefinitionTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("ChargeItemDefinition", js["resourceType"])
        return chargeitemdefinition.ChargeItemDefinition(js)
    
    def testChargeItemDefinition1(self):
        inst = self.instantiate_from("chargeitemdefinition-device-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a ChargeItemDefinition instance")
        self.implChargeItemDefinition1(inst)
        
        js = inst.as_json()
        self.assertEqual("ChargeItemDefinition", js["resourceType"])
        inst2 = chargeitemdefinition.ChargeItemDefinition(js)
        self.implChargeItemDefinition1(inst2)
    
    def implChargeItemDefinition1(self, inst):
        self.assertEqual(force_bytes(inst.applicability[0].description), force_bytes("Verify ChargeItem pertains to Device 12345"))
        self.assertEqual(force_bytes(inst.applicability[0].expression), force_bytes("%context.service.suppliedItem='Device/12345'"))
        self.assertEqual(force_bytes(inst.applicability[0].language), force_bytes("text/fhirpath"))
        self.assertEqual(force_bytes(inst.description), force_bytes("Financial details for  custom made device"))
        self.assertEqual(force_bytes(inst.id), force_bytes("device"))
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[0].amount.currency), force_bytes("EUR"))
        self.assertEqual(inst.propertyGroup[0].priceComponent[0].amount.value, 67.44)
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[0].code.coding[0].code), force_bytes("VK"))
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[0].code.coding[0].display), force_bytes("Verkaufspreis (netto)"))
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[0].code.coding[0].system), force_bytes("http://fhir.de/CodeSystem/billing-attributes"))
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[0].type), force_bytes("base"))
        self.assertEqual(force_bytes(inst.propertyGroup[1].applicability[0].description), force_bytes("Gültigkeit Steuersatz"))
        self.assertEqual(force_bytes(inst.propertyGroup[1].applicability[0].expression), force_bytes("%context.occurenceDateTime > '2018-04-01'"))
        self.assertEqual(force_bytes(inst.propertyGroup[1].applicability[0].language), force_bytes("text/fhirpath"))
        self.assertEqual(force_bytes(inst.propertyGroup[1].priceComponent[0].code.coding[0].code), force_bytes("MWST"))
        self.assertEqual(force_bytes(inst.propertyGroup[1].priceComponent[0].code.coding[0].display), force_bytes("Mehrwersteuersatz"))
        self.assertEqual(force_bytes(inst.propertyGroup[1].priceComponent[0].code.coding[0].system), force_bytes("http://fhir.de/CodeSystem/billing-attributes"))
        self.assertEqual(inst.propertyGroup[1].priceComponent[0].factor, 1.19)
        self.assertEqual(force_bytes(inst.propertyGroup[1].priceComponent[0].type), force_bytes("tax"))
        self.assertEqual(force_bytes(inst.propertyGroup[2].applicability[0].description), force_bytes("Gültigkeit Steuersatz"))
        self.assertEqual(force_bytes(inst.propertyGroup[2].applicability[0].expression), force_bytes("%context.occurenceDateTime <= '2018-04-01'"))
        self.assertEqual(force_bytes(inst.propertyGroup[2].applicability[0].language), force_bytes("text/fhirpath"))
        self.assertEqual(force_bytes(inst.propertyGroup[2].priceComponent[0].code.coding[0].code), force_bytes("MWST"))
        self.assertEqual(force_bytes(inst.propertyGroup[2].priceComponent[0].code.coding[0].display), force_bytes("Mehrwersteuersatz"))
        self.assertEqual(force_bytes(inst.propertyGroup[2].priceComponent[0].code.coding[0].system), force_bytes("http://fhir.de/CodeSystem/billing-attributes"))
        self.assertEqual(inst.propertyGroup[2].priceComponent[0].factor, 1.07)
        self.assertEqual(force_bytes(inst.propertyGroup[2].priceComponent[0].type), force_bytes("tax"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.url), force_bytes("http://sap.org/ChargeItemDefinition/device-123"))
    
    def testChargeItemDefinition2(self):
        inst = self.instantiate_from("chargeitemdefinition-ebm-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a ChargeItemDefinition instance")
        self.implChargeItemDefinition2(inst)
        
        js = inst.as_json()
        self.assertEqual("ChargeItemDefinition", js["resourceType"])
        inst2 = chargeitemdefinition.ChargeItemDefinition(js)
        self.implChargeItemDefinition2(inst2)
    
    def implChargeItemDefinition2(self, inst):
        self.assertEqual(force_bytes(inst.applicability[0].description), force_bytes("Excludes billing code 13250 for same Encounter"))
        self.assertEqual(force_bytes(inst.applicability[0].expression), force_bytes("[some CQL expression]"))
        self.assertEqual(force_bytes(inst.applicability[0].language), force_bytes("text/cql"))
        self.assertEqual(force_bytes(inst.applicability[1].description), force_bytes("Applies only once per Encounter"))
        self.assertEqual(force_bytes(inst.applicability[1].expression), force_bytes("[some CQL expression]"))
        self.assertEqual(force_bytes(inst.applicability[1].language), force_bytes("text/CQL"))
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("30110"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Allergologiediagnostik I"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://fhir.de/CodingSystem/kbv/ebm"))
        self.assertEqual(force_bytes(inst.description), force_bytes("Allergologisch-diagnostischer Komplex zur Diagnostik und/oder zum Ausschluss einer (Kontakt-)Allergie vom Spättyp (Typ IV), einschl. Kosten"))
        self.assertEqual(inst.effectivePeriod.end.date, FHIRDate("2018-06-30").date)
        self.assertEqual(inst.effectivePeriod.end.as_json(), "2018-06-30")
        self.assertEqual(inst.effectivePeriod.start.date, FHIRDate("2018-04-01").date)
        self.assertEqual(inst.effectivePeriod.start.as_json(), "2018-04-01")
        self.assertEqual(force_bytes(inst.id), force_bytes("ebm"))
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[0].amount.currency), force_bytes("EUR"))
        self.assertEqual(inst.propertyGroup[0].priceComponent[0].amount.value, 67.44)
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[0].code.coding[0].code), force_bytes("gesamt-euro"))
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[0].code.coding[0].display), force_bytes("Gesamt (Euro)"))
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[0].code.coding[0].system), force_bytes("http://fhir.de/CodeSystem/kbv/ebm-attribute"))
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[0].type), force_bytes("base"))
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[1].code.coding[0].code), force_bytes("gesamt-punkte"))
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[1].code.coding[0].display), force_bytes("Gesamt (Punkte)"))
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[1].code.coding[0].system), force_bytes("http://fhir.de/CodeSystem/kbv/ebm-attribute"))
        self.assertEqual(inst.propertyGroup[0].priceComponent[1].factor, 633)
        self.assertEqual(force_bytes(inst.propertyGroup[0].priceComponent[1].type), force_bytes("informational"))
        self.assertEqual(force_bytes(inst.status), force_bytes("active"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.url), force_bytes("http://fhir.de/ChargeItemDefinition/kbv/ebm-30110"))
        self.assertEqual(force_bytes(inst.version), force_bytes("2-2018"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b (http://hl7.org/fhir/StructureDefinition/Money) on 2019-05-13.
#  2019, SMART Health IT.


from . import element

class Money(element.Element):
    """ An amount of economic utility in some recognized currency.
    """

    resource_type = "Money"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.currency = None
        """ ISO 4217 Currency Code.
        Type `str`. """

        self.value = None
        """ Numerical value (with implicit precision).
        Type `float`. """

        super(Money, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(Money, self).elementProperties()
        js.extend([
            ("currency", "currency", str, "code", False, None, False),
            ("value", "value", float, "decimal", False, None, False),
        ])
        return js





#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b on 2019-05-13.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json

from .fixtures import force_bytes
from .. import immunizationevaluation
from ..fhirdate import FHIRDate


@pytest.mark.usefixtures("base_settings")
class ImmunizationEvaluationTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("ImmunizationEvaluation", js["resourceType"])
        return immunizationevaluation.ImmunizationEvaluation(js)
    
    def testImmunizationEvaluation1(self):
        inst = self.instantiate_from("immunizationevaluation-example-notvalid.json")
        self.assertIsNotNone(inst, "Must have instantiated a ImmunizationEvaluation instance")
        self.implImmunizationEvaluation1(inst)
        
        js = inst.as_json()
        self.assertEqual("ImmunizationEvaluation", js["resourceType"])
        inst2 = immunizationevaluation.ImmunizationEvaluation(js)
        self.implImmunizationEvaluation1(inst2)
    
    def implImmunizationEvaluation1(self, inst):
        self.assertEqual(inst.date.date, FHIRDate("2013-01-10").date)
        self.assertEqual(inst.date.as_json(), "2013-01-10")
        self.assertEqual(inst.doseNumberPositiveInt, 2)
        self.assertEqual(force_bytes(inst.doseStatus.coding[0].code), force_bytes("notvalid"))
        self.assertEqual(force_bytes(inst.doseStatus.coding[0].display), force_bytes("Not Valid"))
        self.assertEqual(force_bytes(inst.doseStatus.coding[0].system), force_bytes("http://terminology.hl7.org/CodeSystem/immunization-evaluation-dose-status"))
        self.assertEqual(force_bytes(inst.doseStatusReason[0].coding[0].code), force_bytes("outsidesched"))
        self.assertEqual(force_bytes(inst.doseStatusReason[0].coding[0].display), force_bytes("Administered outside recommended schedule"))
        self.assertEqual(force_bytes(inst.doseStatusReason[0].coding[0].system), force_bytes("http://terminology.hl7.org/CodeSystem/immunization-evaluation-dose-status-reason"))
        self.assertEqual(force_bytes(inst.id), force_bytes("notValid"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("urn:ietf:rfc:3986"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("urn:oid:1.3.6.1.4.1.21367.2005.3.7.1234"))
        self.assertEqual(force_bytes(inst.meta.tag[0].code), force_bytes("HTEST"))
        self.assertEqual(force_bytes(inst.meta.tag[0].display), force_bytes("test health data"))
        self.assertEqual(force_bytes(inst.meta.tag[0].system), force_bytes("http://terminology.hl7.org/CodeSystem/v3-ActReason"))
        self.assertEqual(force_bytes(inst.series), force_bytes("Vaccination Series 1"))
        self.assertEqual(inst.seriesDosesPositiveInt, 3)
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.targetDisease.coding[0].code), force_bytes("1857005"))
        self.assertEqual(force_bytes(inst.targetDisease.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
    
    def testImmunizationEvaluation2(self):
        inst = self.instantiate_from("immunizationevaluation-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a ImmunizationEvaluation instance")
        self.implImmunizationEvaluation2(inst)
        
        js = inst.as_json()
        self.assertEqual("ImmunizationEvaluation", js["resourceType"])
        inst2 = immunizationevaluation.ImmunizationEvaluation(js)
        self.implImmunizationEvaluation2(inst2)
    
    def implImmunizationEvaluation2(self, inst):
        self.assertEqual(inst.date.date, FHIRDate("2013-01-10").date)
        self.assertEqual(inst.date.as_json(), "2013-01-10")
        self.assertEqual(inst.doseNumberPositiveInt, 1)
        self.assertEqual(force_bytes(inst.doseStatus.coding[0].code), force_bytes("valid"))
        self.assertEqual(force_bytes(inst.doseStatus.coding[0].display), force_bytes("Valid"))
        self.assertEqual(force_bytes(inst.doseStatus.coding[0].system), force_bytes("http://terminology.hl7.org/CodeSystem/immunization-evaluation-dose-status"))
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("urn:ietf:rfc:3986"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("urn:oid:1.3.6.1.4.1.21367.2005.3.7.1234"))
        self.assertEqual(force_bytes(inst.meta.tag[0].code), force_bytes("HTEST"))
        self.assertEqual(force_bytes(inst.meta.tag[0].display), force_bytes("test health data"))
        self.assertEqual(force_bytes(inst.meta.tag[0].system), force_bytes("http://terminology.hl7.org/CodeSystem/v3-ActReason"))
        self.assertEqual(force_bytes(inst.series), force_bytes("Vaccination Series 1"))
        self.assertEqual(inst.seriesDosesPositiveInt, 3)
        self.assertEqual(force_bytes(inst.status), force_bytes("completed"))
        self.assertEqual(force_bytes(inst.targetDisease.coding[0].code), force_bytes("1857005"))
        self.assertEqual(force_bytes(inst.targetDisease.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b (http://hl7.org/fhir/StructureDefinition/CommunicationRequest) on 2019-05-13.
#  2019, SMART Health IT.


from . import domainresource

class CommunicationRequest(domainresource.DomainResource):
    """ A request for information to be sent to a receiver.

    A request to convey information; e.g. the CDS system proposes that an alert
    be sent to a responsible provider, the CDS system proposes that the public
    health agency be notified about a reportable condition.
    """

    resource_type = "CommunicationRequest"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.about = None
        """ Resources that pertain to this communication request.
        List of `FHIRReference` items (represented as `dict` in JSON). """

        self.authoredOn = None
        """ When request transitioned to being actionable.
        Type `FHIRDate` (represented as `str` in JSON). """

        self.basedOn = None
        """ Fulfills plan or proposal.
        List of `FHIRReference` items (represented as `dict` in JSON). """

        self.category = None
        """ Message category.
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        self.doNotPerform = None
        """ True if request is prohibiting action.
        Type `bool`. """

        self.encounter = None
        """ Encounter created as part of.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.groupIdentifier = None
        """ Composite request this is part of.
        Type `Identifier` (represented as `dict` in JSON). """

        self.identifier = None
        """ Unique identifier.
        List of `Identifier` items (represented as `dict` in JSON). """

        self.medium = None
        """ A channel of communication.
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        self.note = None
        """ Comments made about communication request.
        List of `Annotation` items (represented as `dict` in JSON). """

        self.occurrenceDateTime = None
        """ When scheduled.
        Type `FHIRDate` (represented as `str` in JSON). """

        self.occurrencePeriod = None
        """ When scheduled.
        Type `Period` (represented as `dict` in JSON). """

        self.payload = None
        """ Message payload.
        List of `CommunicationRequestPayload` items (represented as `dict` in JSON). """

        self.priority = None
        """ Message urgency.
        Type `str`. """

        self.reasonCode = None
        """ Why is communication needed?.
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        self.reasonReference = None
        """ Why is communication needed?.
        List of `FHIRReference` items (represented as `dict` in JSON). """

        self.recipient = None
        """ Message recipient.
        List of `FHIRReference` items (represented as `dict` in JSON). """

        self.replaces = None
        """ Request(s) replaced by this request.
        List of `FHIRReference` items (represented as `dict` in JSON). """

        self.requester = None
        """ Who/what is requesting service.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.sender = None
        """ Message sender.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.status = None
        """ draft | active | suspended | cancelled | completed | entered-in-
        error | unknown.
        Type `str`. """

        self.statusReason = None
        """ Reason for current status.
        Type `CodeableConcept` (represented as `dict` in JSON). """

        self.subject = None
        """ Focus of message.
        Type `FHIRReference` (represented as `dict` in JSON). """

        super(CommunicationRequest, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(CommunicationRequest, self).elementProperties()
        js.extend([
            ("about", "about", fhirreference.FHIRReference, "Reference", True, None, False),
            ("authoredOn", "authoredOn", fhirdate.FHIRDate, "dateTime", False, None, False),
            ("basedOn", "basedOn", fhirreference.FHIRReference, "Reference", True, None, False),
            ("category", "category", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
            ("doNotPerform", "doNotPerform", bool, "boolean", False, None, False),
            ("encounter", "encounter", fhirreference.FHIRReference, "Reference", False, None, False),
            ("groupIdentifier", "groupIdentifier", identifier.Identifier, "Identifier", False, None, False),
            ("identifier", "identifier", identifier.Identifier, "Identifier", True, None, False),
            ("medium", "medium", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
            ("note", "note", annotation.Annotation, "Annotation", True, None, False),
            ("occurrenceDateTime", "occurrenceDateTime", fhirdate.FHIRDate, "dateTime", False, "occurrence", False),
            ("occurrencePeriod", "occurrencePeriod", period.Period, "Period", False, "occurrence", False),
            ("payload", "payload", CommunicationRequestPayload, "CommunicationRequestPayload", True, None, False),
            ("priority", "priority", str, "code", False, None, False),
            ("reasonCode", "reasonCode", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
            ("reasonReference", "reasonReference", fhirreference.FHIRReference, "Reference", True, None, False),
            ("recipient", "recipient", fhirreference.FHIRReference, "Reference", True, None, False),
            ("replaces", "replaces", fhirreference.FHIRReference, "Reference", True, None, False),
            ("requester", "requester", fhirreference.FHIRReference, "Reference", False, None, False),
            ("sender", "sender", fhirreference.FHIRReference, "Reference", False, None, False),
            ("status", "status", str, "code", False, None, True),
            ("statusReason", "statusReason", codeableconcept.CodeableConcept, "CodeableConcept", False, None, False),
            ("subject", "subject", fhirreference.FHIRReference, "Reference", False, None, False),
        ])
        return js


from . import backboneelement

class CommunicationRequestPayload(backboneelement.BackboneElement):
    """ Message payload.

    Text, attachment(s), or resource(s) to be communicated to the recipient.
    """

    resource_type = "CommunicationRequestPayload"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.contentAttachment = None
        """ Message part content.
        Type `Attachment` (represented as `dict` in JSON). """

        self.contentReference = None
        """ Message part content.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.contentString = None
        """ Message part content.
        Type `str`. """

        super(CommunicationRequestPayload, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(CommunicationRequestPayload, self).elementProperties()
        js.extend([
            ("contentAttachment", "contentAttachment", attachment.Attachment, "Attachment", False, "content", True),
            ("contentReference", "contentReference", fhirreference.FHIRReference, "Reference", False, "content", True),
            ("contentString", "contentString", str, "string", False, "content", True),
        ])
        return js


import sys
try:
    from . import annotation
except ImportError:
    annotation = sys.modules[__package__ + '.annotation']
try:
    from . import attachment
except ImportError:
    attachment = sys.modules[__package__ + '.attachment']
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
try:
    from . import period
except ImportError:
    period = sys.modules[__package__ + '.period']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b on 2019-05-13.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json

from .fixtures import force_bytes
from .. import messagedefinition
from ..fhirdate import FHIRDate


@pytest.mark.usefixtures("base_settings")
class MessageDefinitionTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("MessageDefinition", js["resourceType"])
        return messagedefinition.MessageDefinition(js)
    
    def testMessageDefinition1(self):
        inst = self.instantiate_from("messagedefinition-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a MessageDefinition instance")
        self.implMessageDefinition1(inst)
        
        js = inst.as_json()
        self.assertEqual("MessageDefinition", js["resourceType"])
        inst2 = messagedefinition.MessageDefinition(js)
        self.implMessageDefinition1(inst2)
    
    def implMessageDefinition1(self, inst):
        self.assertEqual(force_bytes(inst.category), force_bytes("notification"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].system), force_bytes("url"))
        self.assertEqual(force_bytes(inst.contact[0].telecom[0].value), force_bytes("http://hl7.org"))
        self.assertEqual(inst.date.date, FHIRDate("2016-11-09").date)
        self.assertEqual(inst.date.as_json(), "2016-11-09")
        self.assertEqual(force_bytes(inst.eventCoding.code), force_bytes("admin-notify"))
        self.assertEqual(force_bytes(inst.eventCoding.system), force_bytes("http://example.org/fhir/message-events"))
        self.assertTrue(inst.experimental)
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.name), force_bytes("EXAMPLE"))
        self.assertEqual(force_bytes(inst.publisher), force_bytes("Health Level Seven, Int'l"))
        self.assertEqual(force_bytes(inst.purpose), force_bytes("Defines a base example for other MessageDefinition instances."))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">Message definition base example</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.title), force_bytes("Message definition base example"))
        self.assertEqual(force_bytes(inst.url), force_bytes("http://hl7.org/fhir/MessageDefinition/example"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b on 2019-05-13.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json

from .fixtures import force_bytes
from .. import medicinalproductauthorization
from ..fhirdate import FHIRDate


@pytest.mark.usefixtures("base_settings")
class MedicinalProductAuthorizationTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("MedicinalProductAuthorization", js["resourceType"])
        return medicinalproductauthorization.MedicinalProductAuthorization(js)
    
    def testMedicinalProductAuthorization1(self):
        inst = self.instantiate_from("medicinalproductauthorization-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a MedicinalProductAuthorization instance")
        self.implMedicinalProductAuthorization1(inst)
        
        js = inst.as_json()
        self.assertEqual("MedicinalProductAuthorization", js["resourceType"])
        inst2 = medicinalproductauthorization.MedicinalProductAuthorization(js)
        self.implMedicinalProductAuthorization1(inst2)
    
    def implMedicinalProductAuthorization1(self, inst):
        self.assertEqual(force_bytes(inst.country[0].coding[0].code), force_bytes("EU"))
        self.assertEqual(force_bytes(inst.country[0].coding[0].system), force_bytes("http://ema.europa.eu/example/country"))
        self.assertEqual(inst.dataExclusivityPeriod.end.date, FHIRDate("2020-08-15").date)
        self.assertEqual(inst.dataExclusivityPeriod.end.as_json(), "2020-08-15")
        self.assertEqual(inst.dataExclusivityPeriod.start.date, FHIRDate("2010-08-15").date)
        self.assertEqual(inst.dataExclusivityPeriod.start.as_json(), "2010-08-15")
        self.assertEqual(inst.dateOfFirstAuthorization.date, FHIRDate("2010-08-15").date)
        self.assertEqual(inst.dateOfFirstAuthorization.as_json(), "2010-08-15")
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://ema.europa.eu/example/marketingAuthorisationNumber"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("EU/1/11/999/001"))
        self.assertEqual(inst.internationalBirthDate.date, FHIRDate("2010-08-15").date)
        self.assertEqual(inst.internationalBirthDate.as_json(), "2010-08-15")
        self.assertEqual(force_bytes(inst.jurisdictionalAuthorization[0].country.coding[0].code), force_bytes("NO"))
        self.assertEqual(force_bytes(inst.jurisdictionalAuthorization[0].country.coding[0].system), force_bytes("http://ema.europa.eu/example/countryCode"))
        self.assertEqual(force_bytes(inst.jurisdictionalAuthorization[0].id), force_bytes("1"))
        self.assertEqual(force_bytes(inst.jurisdictionalAuthorization[0].identifier[0].system), force_bytes("http://ema.europa.eu/example/marketingauthorisationnumber"))
        self.assertEqual(force_bytes(inst.jurisdictionalAuthorization[0].identifier[0].value), force_bytes("123-456-789"))
        self.assertEqual(force_bytes(inst.jurisdictionalAuthorization[1].country.coding[0].code), force_bytes("NO"))
        self.assertEqual(force_bytes(inst.jurisdictionalAuthorization[1].country.coding[0].system), force_bytes("http://ema.europa.eu/example/countryCode"))
        self.assertEqual(force_bytes(inst.jurisdictionalAuthorization[1].id), force_bytes("2"))
        self.assertEqual(force_bytes(inst.jurisdictionalAuthorization[1].identifier[0].system), force_bytes("http://ema.europa.eu/example/marketingauthorisationnumber"))
        self.assertEqual(force_bytes(inst.jurisdictionalAuthorization[1].identifier[0].value), force_bytes("123-456-123"))
        self.assertEqual(force_bytes(inst.meta.tag[0].code), force_bytes("HTEST"))
        self.assertEqual(force_bytes(inst.meta.tag[0].display), force_bytes("test health data"))
        self.assertEqual(force_bytes(inst.meta.tag[0].system), force_bytes("http://terminology.hl7.org/CodeSystem/v3-ActReason"))
        self.assertEqual(inst.procedure.application[0].dateDateTime.date, FHIRDate("2015-08-01").date)
        self.assertEqual(inst.procedure.application[0].dateDateTime.as_json(), "2015-08-01")
        self.assertEqual(force_bytes(inst.procedure.application[0].identifier.system), force_bytes("http://ema.europa.eu/example/applicationidentifier-number"))
        self.assertEqual(force_bytes(inst.procedure.application[0].identifier.value), force_bytes("IA38G"))
        self.assertEqual(force_bytes(inst.procedure.application[0].type.coding[0].code), force_bytes("GroupTypeIAVariationNotification"))
        self.assertEqual(force_bytes(inst.procedure.application[0].type.coding[0].system), force_bytes("http://ema.europa.eu/example/marketingAuthorisationApplicationType"))
        self.assertEqual(inst.procedure.datePeriod.end.date, FHIRDate("2015-08-21").date)
        self.assertEqual(inst.procedure.datePeriod.end.as_json(), "2015-08-21")
        self.assertEqual(inst.procedure.datePeriod.start.date, FHIRDate("2015-08-02").date)
        self.assertEqual(inst.procedure.datePeriod.start.as_json(), "2015-08-02")
        self.assertEqual(force_bytes(inst.procedure.identifier.system), force_bytes("http://ema.europa.eu/example/procedureidentifier-number"))
        self.assertEqual(force_bytes(inst.procedure.identifier.value), force_bytes("EMEA/H/C/009999/IA/0099/G"))
        self.assertEqual(force_bytes(inst.procedure.type.coding[0].code), force_bytes("VariationTypeIA"))
        self.assertEqual(force_bytes(inst.procedure.type.coding[0].system), force_bytes("http://ema.europa.eu/example/marketingAuthorisationProcedureType"))
        self.assertEqual(force_bytes(inst.status.coding[0].code), force_bytes("active"))
        self.assertEqual(force_bytes(inst.status.coding[0].system), force_bytes("http://ema.europa.eu/example/authorisationstatus"))
        self.assertEqual(inst.statusDate.date, FHIRDate("2015-01-14").date)
        self.assertEqual(inst.statusDate.as_json(), "2015-01-14")
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(inst.validityPeriod.end.date, FHIRDate("2020-05-20").date)
        self.assertEqual(inst.validityPeriod.end.as_json(), "2020-05-20")
        self.assertEqual(inst.validityPeriod.start.date, FHIRDate("2015-08-16").date)
        self.assertEqual(inst.validityPeriod.start.as_json(), "2015-08-16")




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b (http://hl7.org/fhir/StructureDefinition/ResearchDefinition) on 2019-05-13.
#  2019, SMART Health IT.


from . import domainresource

class ResearchDefinition(domainresource.DomainResource):
    """ A research context or question.

    The ResearchDefinition resource describes the conditional state (population
    and any exposures being compared within the population) and outcome (if
    specified) that the knowledge (evidence, assertion, recommendation) is
    about.
    """

    resource_type = "ResearchDefinition"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.approvalDate = None
        """ When the research definition was approved by publisher.
        Type `FHIRDate` (represented as `str` in JSON). """

        self.author = None
        """ Who authored the content.
        List of `ContactDetail` items (represented as `dict` in JSON). """

        self.comment = None
        """ Used for footnotes or explanatory notes.
        List of `str` items. """

        self.contact = None
        """ Contact details for the publisher.
        List of `ContactDetail` items (represented as `dict` in JSON). """

        self.copyright = None
        """ Use and/or publishing restrictions.
        Type `str`. """

        self.date = None
        """ Date last changed.
        Type `FHIRDate` (represented as `str` in JSON). """

        self.description = None
        """ Natural language description of the research definition.
        Type `str`. """

        self.editor = None
        """ Who edited the content.
        List of `ContactDetail` items (represented as `dict` in JSON). """

        self.effectivePeriod = None
        """ When the research definition is expected to be used.
        Type `Period` (represented as `dict` in JSON). """

        self.endorser = None
        """ Who endorsed the content.
        List of `ContactDetail` items (represented as `dict` in JSON). """

        self.experimental = None
        """ For testing purposes, not real usage.
        Type `bool`. """

        self.exposure = None
        """ What exposure?.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.exposureAlternative = None
        """ What alternative exposure state?.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.identifier = None
        """ Additional identifier for the research definition.
        List of `Identifier` items (represented as `dict` in JSON). """

        self.jurisdiction = None
        """ Intended jurisdiction for research definition (if applicable).
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        self.lastReviewDate = None
        """ When the research definition was last reviewed.
        Type `FHIRDate` (represented as `str` in JSON). """

        self.library = None
        """ Logic used by the ResearchDefinition.
        List of `str` items. """

        self.name = None
        """ Name for this research definition (computer friendly).
        Type `str`. """

        self.outcome = None
        """ What outcome?.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.population = None
        """ What population?.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.publisher = None
        """ Name of the publisher (organization or individual).
        Type `str`. """

        self.purpose = None
        """ Why this research definition is defined.
        Type `str`. """

        self.relatedArtifact = None
        """ Additional documentation, citations, etc..
        List of `RelatedArtifact` items (represented as `dict` in JSON). """

        self.reviewer = None
        """ Who reviewed the content.
        List of `ContactDetail` items (represented as `dict` in JSON). """

        self.shortTitle = None
        """ Title for use in informal contexts.
        Type `str`. """

        self.status = None
        """ draft | active | retired | unknown.
        Type `str`. """

        self.subjectCodeableConcept = None
        """ E.g. Patient, Practitioner, RelatedPerson, Organization, Location,
        Device.
        Type `CodeableConcept` (represented as `dict` in JSON). """

        self.subjectReference = None
        """ E.g. Patient, Practitioner, RelatedPerson, Organization, Location,
        Device.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.subtitle = None
        """ Subordinate title of the ResearchDefinition.
        Type `str`. """

        self.title = None
        """ Name for this research definition (human friendly).
        Type `str`. """

        self.topic = None
        """ The category of the ResearchDefinition, such as Education,
        Treatment, Assessment, etc..
        List of `CodeableConcept` items (represented as `dict` in JSON). """

        self.url = None
        """ Canonical identifier for this research definition, represented as a
        URI (globally unique).
        Type `str`. """

        self.usage = None
        """ Describes the clinical usage of the ResearchDefinition.
        Type `str`. """

        self.useContext = None
        """ The context that the content is intended to support.
        List of `UsageContext` items (represented as `dict` in JSON). """

        self.version = None
        """ Business version of the research definition.
        Type `str`. """

        super(ResearchDefinition, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(ResearchDefinition, self).elementProperties()
        js.extend([
            ("approvalDate", "approvalDate", fhirdate.FHIRDate, "date", False, None, False),
            ("author", "author", contactdetail.ContactDetail, "ContactDetail", True, None, False),
            ("comment", "comment", str, "string", True, None, False),
            ("contact", "contact", contactdetail.ContactDetail, "ContactDetail", True, None, False),
            ("copyright", "copyright", str, "markdown", False, None, False),
            ("date", "date", fhirdate.FHIRDate, "dateTime", False, None, False),
            ("description", "description", str, "markdown", False, None, False),
            ("editor", "editor", contactdetail.ContactDetail, "ContactDetail", True, None, False),
            ("effectivePeriod", "effectivePeriod", period.Period, "Period", False, None, False),
            ("endorser", "endorser", contactdetail.ContactDetail, "ContactDetail", True, None, False),
            ("experimental", "experimental", bool, "boolean", False, None, False),
            ("exposure", "exposure", fhirreference.FHIRReference, "Reference", False, None, False),
            ("exposureAlternative", "exposureAlternative", fhirreference.FHIRReference, "Reference", False, None, False),
            ("identifier", "identifier", identifier.Identifier, "Identifier", True, None, False),
            ("jurisdiction", "jurisdiction", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
            ("lastReviewDate", "lastReviewDate", fhirdate.FHIRDate, "date", False, None, False),
            ("library", "library", str, "canonical", True, None, False),
            ("name", "name", str, "string", False, None, False),
            ("outcome", "outcome", fhirreference.FHIRReference, "Reference", False, None, False),
            ("population", "population", fhirreference.FHIRReference, "Reference", False, None, True),
            ("publisher", "publisher", str, "string", False, None, False),
            ("purpose", "purpose", str, "markdown", False, None, False),
            ("relatedArtifact", "relatedArtifact", relatedartifact.RelatedArtifact, "RelatedArtifact", True, None, False),
            ("reviewer", "reviewer", contactdetail.ContactDetail, "ContactDetail", True, None, False),
            ("shortTitle", "shortTitle", str, "string", False, None, False),
            ("status", "status", str, "code", False, None, True),
            ("subjectCodeableConcept", "subjectCodeableConcept", codeableconcept.CodeableConcept, "CodeableConcept", False, "subject", False),
            ("subjectReference", "subjectReference", fhirreference.FHIRReference, "Reference", False, "subject", False),
            ("subtitle", "subtitle", str, "string", False, None, False),
            ("title", "title", str, "string", False, None, False),
            ("topic", "topic", codeableconcept.CodeableConcept, "CodeableConcept", True, None, False),
            ("url", "url", str, "uri", False, None, False),
            ("usage", "usage", str, "string", False, None, False),
            ("useContext", "useContext", usagecontext.UsageContext, "UsageContext", True, None, False),
            ("version", "version", str, "string", False, None, False),
        ])
        return js


import sys
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import contactdetail
except ImportError:
    contactdetail = sys.modules[__package__ + '.contactdetail']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
try:
    from . import period
except ImportError:
    period = sys.modules[__package__ + '.period']
try:
    from . import relatedartifact
except ImportError:
    relatedartifact = sys.modules[__package__ + '.relatedartifact']
try:
    from . import usagecontext
except ImportError:
    usagecontext = sys.modules[__package__ + '.usagecontext']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b on 2019-05-13.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json

from .fixtures import force_bytes
from .. import group
from ..fhirdate import FHIRDate


@pytest.mark.usefixtures("base_settings")
class GroupTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("Group", js["resourceType"])
        return group.Group(js)
    
    def testGroup1(self):
        inst = self.instantiate_from("group-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a Group instance")
        self.implGroup1(inst)
        
        js = inst.as_json()
        self.assertEqual("Group", js["resourceType"])
        inst2 = group.Group(js)
        self.implGroup1(inst2)
    
    def implGroup1(self, inst):
        self.assertTrue(inst.actual)
        self.assertEqual(force_bytes(inst.characteristic[0].code.text), force_bytes("gender"))
        self.assertFalse(inst.characteristic[0].exclude)
        self.assertEqual(force_bytes(inst.characteristic[0].valueCodeableConcept.text), force_bytes("mixed"))
        self.assertEqual(force_bytes(inst.characteristic[1].code.text), force_bytes("owner"))
        self.assertFalse(inst.characteristic[1].exclude)
        self.assertEqual(force_bytes(inst.characteristic[1].valueCodeableConcept.text), force_bytes("John Smith"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Horse"))
        self.assertEqual(force_bytes(inst.id), force_bytes("101"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("http://someveterinarianclinic.org/fhir/NamingSystem/herds"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("12345"))
        self.assertEqual(force_bytes(inst.meta.tag[0].code), force_bytes("HTEST"))
        self.assertEqual(force_bytes(inst.meta.tag[0].display), force_bytes("test health data"))
        self.assertEqual(force_bytes(inst.meta.tag[0].system), force_bytes("http://terminology.hl7.org/CodeSystem/v3-ActReason"))
        self.assertEqual(force_bytes(inst.name), force_bytes("John's herd"))
        self.assertEqual(inst.quantity, 25)
        self.assertEqual(force_bytes(inst.text.status), force_bytes("additional"))
        self.assertEqual(force_bytes(inst.type), force_bytes("animal"))
    
    def testGroup2(self):
        inst = self.instantiate_from("group-example-member.json")
        self.assertIsNotNone(inst, "Must have instantiated a Group instance")
        self.implGroup2(inst)
        
        js = inst.as_json()
        self.assertEqual("Group", js["resourceType"])
        inst2 = group.Group(js)
        self.implGroup2(inst2)
    
    def implGroup2(self, inst):
        self.assertTrue(inst.actual)
        self.assertEqual(force_bytes(inst.id), force_bytes("102"))
        self.assertEqual(inst.member[0].period.start.date, FHIRDate("2014-10-08").date)
        self.assertEqual(inst.member[0].period.start.as_json(), "2014-10-08")
        self.assertTrue(inst.member[1].inactive)
        self.assertEqual(inst.member[1].period.start.date, FHIRDate("2015-04-02").date)
        self.assertEqual(inst.member[1].period.start.as_json(), "2015-04-02")
        self.assertEqual(inst.member[2].period.start.date, FHIRDate("2015-08-06").date)
        self.assertEqual(inst.member[2].period.start.as_json(), "2015-08-06")
        self.assertEqual(inst.member[3].period.start.date, FHIRDate("2015-08-06").date)
        self.assertEqual(inst.member[3].period.start.as_json(), "2015-08-06")
        self.assertEqual(force_bytes(inst.meta.tag[0].code), force_bytes("HTEST"))
        self.assertEqual(force_bytes(inst.meta.tag[0].display), force_bytes("test health data"))
        self.assertEqual(force_bytes(inst.meta.tag[0].system), force_bytes("http://terminology.hl7.org/CodeSystem/v3-ActReason"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("additional"))
        self.assertEqual(force_bytes(inst.type), force_bytes("person"))
    
    def testGroup3(self):
        inst = self.instantiate_from("group-example-herd1.json")
        self.assertIsNotNone(inst, "Must have instantiated a Group instance")
        self.implGroup3(inst)
        
        js = inst.as_json()
        self.assertEqual("Group", js["resourceType"])
        inst2 = group.Group(js)
        self.implGroup3(inst2)
    
    def implGroup3(self, inst):
        self.assertTrue(inst.active)
        self.assertTrue(inst.actual)
        self.assertEqual(force_bytes(inst.characteristic[0].code.text), force_bytes("gender"))
        self.assertFalse(inst.characteristic[0].exclude)
        self.assertEqual(force_bytes(inst.characteristic[0].valueCodeableConcept.text), force_bytes("female"))
        self.assertEqual(force_bytes(inst.code.coding[0].code), force_bytes("388393002"))
        self.assertEqual(force_bytes(inst.code.coding[0].display), force_bytes("Genus Sus (organism)"))
        self.assertEqual(force_bytes(inst.code.coding[0].system), force_bytes("http://snomed.info/sct"))
        self.assertEqual(force_bytes(inst.code.coding[1].code), force_bytes("POR"))
        self.assertEqual(force_bytes(inst.code.coding[1].display), force_bytes("porcine"))
        self.assertEqual(force_bytes(inst.code.coding[1].system), force_bytes("https://www.aphis.usda.gov"))
        self.assertEqual(force_bytes(inst.code.text), force_bytes("Porcine"))
        self.assertEqual(force_bytes(inst.extension[0].url), force_bytes("http://example.org/fhir/StructureDefinition/owner"))
        self.assertEqual(force_bytes(inst.id), force_bytes("herd1"))
        self.assertEqual(force_bytes(inst.identifier[0].system), force_bytes("https://vetmed.iastate.edu/vdl"))
        self.assertEqual(force_bytes(inst.identifier[0].value), force_bytes("20171120-1234"))
        self.assertEqual(force_bytes(inst.meta.tag[0].code), force_bytes("HTEST"))
        self.assertEqual(force_bytes(inst.meta.tag[0].display), force_bytes("test health data"))
        self.assertEqual(force_bytes(inst.meta.tag[0].system), force_bytes("http://terminology.hl7.org/CodeSystem/v3-ActReason"))
        self.assertEqual(force_bytes(inst.name), force_bytes("Breeding herd"))
        self.assertEqual(inst.quantity, 2500)
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))
        self.assertEqual(force_bytes(inst.type), force_bytes("animal"))
    
    def testGroup4(self):
        inst = self.instantiate_from("group-example-patientlist.json")
        self.assertIsNotNone(inst, "Must have instantiated a Group instance")
        self.implGroup4(inst)
        
        js = inst.as_json()
        self.assertEqual("Group", js["resourceType"])
        inst2 = group.Group(js)
        self.implGroup4(inst2)
    
    def implGroup4(self, inst):
        self.assertTrue(inst.actual)
        self.assertEqual(force_bytes(inst.characteristic[0].code.coding[0].code), force_bytes("attributed-to"))
        self.assertEqual(force_bytes(inst.characteristic[0].code.coding[0].system), force_bytes("http://example.org"))
        self.assertEqual(force_bytes(inst.characteristic[0].code.text), force_bytes("Patients primarily attributed to"))
        self.assertFalse(inst.characteristic[0].exclude)
        self.assertEqual(force_bytes(inst.id), force_bytes("example-patientlist"))
        self.assertEqual(force_bytes(inst.meta.tag[0].code), force_bytes("HTEST"))
        self.assertEqual(force_bytes(inst.meta.tag[0].display), force_bytes("test health data"))
        self.assertEqual(force_bytes(inst.meta.tag[0].system), force_bytes("http://terminology.hl7.org/CodeSystem/v3-ActReason"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("additional"))
        self.assertEqual(force_bytes(inst.type), force_bytes("person"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b on 2019-05-13.
#  2019, SMART Health IT.

import os
import pytest
import io
import unittest
import json

from .fixtures import force_bytes
from .. import evidencevariable
from ..fhirdate import FHIRDate


@pytest.mark.usefixtures("base_settings")
class EvidenceVariableTests(unittest.TestCase):
    def instantiate_from(self, filename):
        datadir = os.environ.get('FHIR_UNITTEST_DATADIR') or ''
        with io.open(os.path.join(datadir, filename), 'r', encoding='utf-8') as handle:
            js = json.load(handle)
            self.assertEqual("EvidenceVariable", js["resourceType"])
        return evidencevariable.EvidenceVariable(js)
    
    def testEvidenceVariable1(self):
        inst = self.instantiate_from("evidencevariable-example.json")
        self.assertIsNotNone(inst, "Must have instantiated a EvidenceVariable instance")
        self.implEvidenceVariable1(inst)
        
        js = inst.as_json()
        self.assertEqual("EvidenceVariable", js["resourceType"])
        inst2 = evidencevariable.EvidenceVariable(js)
        self.implEvidenceVariable1(inst2)
    
    def implEvidenceVariable1(self, inst):
        self.assertEqual(force_bytes(inst.characteristic[0].definitionCodeableConcept.text), force_bytes("Diabetic patients over 65"))
        self.assertEqual(force_bytes(inst.id), force_bytes("example"))
        self.assertEqual(force_bytes(inst.meta.tag[0].code), force_bytes("HTEST"))
        self.assertEqual(force_bytes(inst.meta.tag[0].display), force_bytes("test health data"))
        self.assertEqual(force_bytes(inst.meta.tag[0].system), force_bytes("http://terminology.hl7.org/CodeSystem/v3-ActReason"))
        self.assertEqual(force_bytes(inst.status), force_bytes("draft"))
        self.assertEqual(force_bytes(inst.text.div), force_bytes("<div xmlns=\"http://www.w3.org/1999/xhtml\">[Put rendering here]</div>"))
        self.assertEqual(force_bytes(inst.text.status), force_bytes("generated"))




#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#  Generated from FHIR 4.0.0-a53ec6ee1b (http://hl7.org/fhir/StructureDefinition/List) on 2019-05-13.
#  2019, SMART Health IT.


from . import domainresource

class List(domainresource.DomainResource):
    """ A list is a curated collection of resources.
    """

    resource_type = "List"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.code = None
        """ What the purpose of this list is.
        Type `CodeableConcept` (represented as `dict` in JSON). """

        self.date = None
        """ When the list was prepared.
        Type `FHIRDate` (represented as `str` in JSON). """

        self.emptyReason = None
        """ Why list is empty.
        Type `CodeableConcept` (represented as `dict` in JSON). """

        self.encounter = None
        """ Context in which list created.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.entry = None
        """ Entries in the list.
        List of `ListEntry` items (represented as `dict` in JSON). """

        self.identifier = None
        """ Business identifier.
        List of `Identifier` items (represented as `dict` in JSON). """

        self.mode = None
        """ working | snapshot | changes.
        Type `str`. """

        self.note = None
        """ Comments about the list.
        List of `Annotation` items (represented as `dict` in JSON). """

        self.orderedBy = None
        """ What order the list has.
        Type `CodeableConcept` (represented as `dict` in JSON). """

        self.source = None
        """ Who and/or what defined the list contents (aka Author).
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.status = None
        """ current | retired | entered-in-error.
        Type `str`. """

        self.subject = None
        """ If all resources have the same subject.
        Type `FHIRReference` (represented as `dict` in JSON). """

        self.title = None
        """ Descriptive name for the list.
        Type `str`. """

        super(List, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(List, self).elementProperties()
        js.extend([
            ("code", "code", codeableconcept.CodeableConcept, "CodeableConcept", False, None, False),
            ("date", "date", fhirdate.FHIRDate, "dateTime", False, None, False),
            ("emptyReason", "emptyReason", codeableconcept.CodeableConcept, "CodeableConcept", False, None, False),
            ("encounter", "encounter", fhirreference.FHIRReference, "Reference", False, None, False),
            ("entry", "entry", ListEntry, "ListEntry", True, None, False),
            ("identifier", "identifier", identifier.Identifier, "Identifier", True, None, False),
            ("mode", "mode", str, "code", False, None, True),
            ("note", "note", annotation.Annotation, "Annotation", True, None, False),
            ("orderedBy", "orderedBy", codeableconcept.CodeableConcept, "CodeableConcept", False, None, False),
            ("source", "source", fhirreference.FHIRReference, "Reference", False, None, False),
            ("status", "status", str, "code", False, None, True),
            ("subject", "subject", fhirreference.FHIRReference, "Reference", False, None, False),
            ("title", "title", str, "string", False, None, False),
        ])
        return js


from . import backboneelement

class ListEntry(backboneelement.BackboneElement):
    """ Entries in the list.

    Entries in this list.
    """

    resource_type = "ListEntry"

    def __init__(self, jsondict=None, strict=True):
        """ Initialize all valid properties.

        :raises: FHIRValidationError on validation errors, unless strict is False
        :param dict jsondict: A JSON dictionary to use for initialization
        :param bool strict: If True (the default), invalid variables will raise a TypeError
        """

        self.date = None
        """ When item added to list.
        Type `FHIRDate` (represented as `str` in JSON). """

        self.deleted = None
        """ If this item is actually marked as deleted.
        Type `bool`. """

        self.flag = None
        """ Status/Workflow information about this item.
        Type `CodeableConcept` (represented as `dict` in JSON). """

        self.item = None
        """ Actual entry.
        Type `FHIRReference` (represented as `dict` in JSON). """

        super(ListEntry, self).__init__(jsondict=jsondict, strict=strict)

    def elementProperties(self):
        js = super(ListEntry, self).elementProperties()
        js.extend([
            ("date", "date", fhirdate.FHIRDate, "dateTime", False, None, False),
            ("deleted", "deleted", bool, "boolean", False, None, False),
            ("flag", "flag", codeableconcept.CodeableConcept, "CodeableConcept", False, None, False),
            ("item", "item", fhirreference.FHIRReference, "Reference", False, None, True),
        ])
        return js


import sys
try:
    from . import annotation
except ImportError:
    annotation = sys.modules[__package__ + '.annotation']
try:
    from . import codeableconcept
except ImportError:
    codeableconcept = sys.modules[__package__ + '.codeableconcept']
try:
    from . import fhirdate
except ImportError:
    fhirdate = sys.modules[__package__ + '.fhirdate']
try:
    from . import fhirreference
except ImportError:
    fhirreference = sys.modules[__package__ + '.fhirreference']
try:
    from . import identifier
except ImportError:
    identifier = sys.modules[__package__ + '.identifier']
